spoon.ber.common

Package spoon :: Package ber :: Module common |
[hide private]
[frames] | no frames]

# Module common

source code

Classes | [hide private]
`` | BERException

Functions | [hide private]
`` | inflate_long(s, always_positive=False) turns a normalized byte string into a long-int (adapted from Crypto.Util.number)
`` | deflate_long(n, add_sign_padding=True) turns a long-int into a normalized byte string (adapted from Crypto.Util.number)

Variables | [hide private]
`` | UNIVERSAL = `0`
`` | APPLICATION = `1`
`` | CONTEXT = `2`
`` | PRIVATE = `3`

Function Details | [hide private]

### inflate_long(s, always_positive=False) | source code
turns a normalized byte string into a long-int (adapted from Crypto.Util.number)

### deflate_long(n, add_sign_padding=True) | source code
turns a long-int into a normalized byte string (adapted from Crypto.Util.number)

Variables Details | [hide private]

    ### UNIVERSAL None Value:
        0

    ### APPLICATION None Value:
        1

    ### CONTEXT None Value:
        2

    ### PRIVATE None Value:
        3